@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 10057 2017-06-18 15:16:01Z David $
+# $Id: __init__.py 10059 2017-06-18 17:13:12Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $ (last)
-# $Date: 2017-06-18 23:16:01 +0800 (Sun, 18 Jun 2017) $
-# $Revision: 10057 $
+# $Date: 2017-06-19 01:13:12 +0800 (Mon, 19 Jun 2017) $
+# $Revision: 10059 $
 
 import os
 import sys
@@ -75,6 +75,7 @@ def attachSettings(settingsDict, enableFacebook=False, enableGoogle=False,
     authenticationBackends = [            
         'account.auth_backends.EmailAuthenticationBackend',
         'django.contrib.auth.backends.ModelBackend',
+        'social_core.backends.open_id.OpenIdAuth',
     ]
     
     if enableFacebook:
@@ -118,16 +119,15 @@ def attachSettings(settingsDict, enableFacebook=False, enableGoogle=False,
     #  social_auth pipeline.
     socialAuthPipelineDefaults = {
         'SOCIAL_AUTH_PIPELINE' : ( 
-            'social.pipeline.social_auth.social_details',
-            'social.pipeline.social_auth.social_uid',
-            'social.pipeline.social_auth.auth_allowed',
-            'social.pipeline.social_auth.social_user',
-            'social.pipeline.user.get_username',
-            'social.pipeline.user.create_user',
-            #'path.to.save_profile',  # <--- set the path to the function
-            'social.pipeline.social_auth.associate_user',
-            'social.pipeline.social_auth.load_extra_data',
-            'social.pipeline.user.user_details',
+            'social_core.pipeline.social_auth.social_details',
+            'social_core.pipeline.social_auth.social_uid',
+            'social_core.pipeline.social_auth.social_user',
+            'social_core.pipeline.user.get_username',
+            'social_core.pipeline.user.create_user',
+            'social_core.pipeline.social_auth.associate_user',
+            'social_core.pipeline.social_auth.load_extra_data',
+            'social_core.pipeline.user.user_details',
+            'social_core.pipeline.social_auth.associate_by_email',
         ) 
     }
 
